@@ -1,4 +1,4 @@
-//@line 42 "/builds/tinderbox/XR-Trunk/Linux_2.6.18-53.1.14.el5_Depend/mozilla/toolkit/components/printing/content/printdialog.js"
+//@line 42 "/builds/slave/191-lnx-xr/build/toolkit/components/printing/content/printdialog.js"
 
 var dialog;
 var printService       = null;
@@ -109,9 +109,10 @@ listElement.prototype =
         { 
           if ((null == aDataObject) || !aDataObject.hasMore()) {
             // disable dialog
-            var stringBundle = srGetStrBundle("chrome://global/locale/printing.properties");
             this.listElement.setAttribute("value", "");
-            this.listElement.setAttribute("label", stringBundle.GetStringFromName("noprinter"));
+            this.listElement.setAttribute("label",
+              document.getElementById("printingBundle")
+                      .getString("noprinter"));
 
             this.listElement.setAttribute("disabled", "true");
             dialog.printerLabel.setAttribute("disabled","true");
